@@ -131,45 +131,47 @@
 ##' \dontrun{theData <- importAURN(site = "kc1", year = 2009)
 ##' mytraj <- merge(mytraj, theData, by = "date")}
 importTraj <- function(site = "london", year = 2009, local = NA) {
-  
+
   ## get rid of R check annoyances
-  traj = NULL
-  
+  traj <- NULL
+
   if (length(site) > 1) stop("Only one site can be imported at a time.")
   site <- tolower(site)
-  
-  files <- lapply(site, function (x) paste(x, year, sep = ""))
+
+  files <- lapply(site, function(x) paste(x, year, sep = ""))
   files <- do.call(c, files)
-  
+
   loadData <- function(x) {
     tryCatch({
-      
       if (is.na(local)) {
-        fileName <- paste("http://met-data.ricardo-aea.com/trajectories/", x, ".RData",
-                          sep = "")
-        
+        fileName <- paste(
+          "http://met-data.ricardo-aea.com/trajectories/", x, ".RData",
+          sep = ""
+        )
+
         con <- url(fileName)
         load(con)
         close(con)
-        
       } else { ## load from local file system
-        
+
         con <- paste(local, x, ".RData", sep = "")
         load(con)
-        
       }
-      
-      
+
+
       traj
     },
-    error = function(ex) {cat(x, "does not exist - ignoring that one.\n")})
+    error = function(ex) {
+      cat(x, "does not exist - ignoring that one.\n")
+    }
+    )
   }
-  
+
   thedata <- lapply(files, loadData)
   thedata <- do.call(bind_rows, thedata)
-  
+
   ## change names
   names(thedata) <- tolower(names(thedata))
-  
+
   thedata
 }
